SPLogger class
Constructors
- SPLogger()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- errorLogsEnabled → bool
-
final
- infoLogsEnabled → bool
-
final
- integrationSdkLogsEnabled → bool
-
final
- warningLogsEnabled → bool
-
final
Static Methods
-
d(
String tag, String msg) → void - Debug log
-
de(
String tag, String msg, [Object? error, StackTrace? stack]) → void - Debug log with error/exception
-
e(
String tag, String msg, [Object? error, StackTrace? stack]) → void - Error log
-
i(
String tag, String msg) → void - Info log
-
w(
String tag, String msg) → void - Warning log